@@ -1,4 +1,4 @@
-from sqlconnection import logger # for __init__ loading
+from sqlconnection import logger  # Must for __init__ loading
 import os
 import psycopg2
 
